<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="ja_JP" sourcelanguage="">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config.py" line="67"/>
        <source>Behavior</source>
        <translation>動作設定</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically save documents</source>
        <translation>文書を自動保存する</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Restore window geometry</source>
        <translation>ウィンドウの表示位置を記憶する</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Open external links in ReText window</source>
        <translation>外部リンクを ReText ウィンドウ内で開く</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Markdown syntax extensions (comma-separated)</source>
        <translation>Markdown記法の拡張(カンマ区切り)</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Editor</source>
        <translation>エディタ</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Highlight current line</source>
        <translation>カーソル行をハイライト表示する</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Show line numbers</source>
        <translation>行番号を表示する</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tab key inserts spaces</source>
        <translation>タブをスペースに展開</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Tabulation width</source>
        <translation>タブの桁数</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Interface</source>
        <translation>外観</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Icon theme name</source>
        <translation>アイコンテーマ名</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Stylesheet file</source>
        <translation>スタイルシートファイル</translation>
    </message>
    <message>
        <location filename="config.py" line="104"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Use live preview by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Enable synchronized scrolling for Markdown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Draw vertical line at column</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="config.py" line="67"/>
        <source>Automatically open last documents on startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileSelectButton</name>
    <message>
        <location filename="config.py" line="34"/>
        <source>(none)</source>
        <translation>（未設定）</translation>
    </message>
    <message>
        <location filename="config.py" line="41"/>
        <source>Select file to open</source>
        <translation>ファイルを開く</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="dialogs.py" line="44"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>ロケール名を入力してください (例：ja_JP)</translation>
    </message>
    <message>
        <location filename="dialogs.py" line="50"/>
        <source>Set as default</source>
        <translation>デフォルトにする</translation>
    </message>
</context>
<context>
    <name>Proxy</name>
    <message>
        <location filename="fakevimeditor.py" line="64"/>
        <source>No write since last change (add ! to override)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="fakevimeditor.py" line="121"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextEdit</name>
    <message>
        <location filename="editor.py" line="295"/>
        <source>Save image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="editor.py" line="295"/>
        <source>Images (*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ReTextTab</name>
    <message>
        <location filename="tab.py" line="183"/>
        <source>New document</source>
        <translation>新規文書</translation>
    </message>
    <message>
        <location filename="tab.py" line="188"/>
        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
        <translation>ファイルの内容を解析できません。&lt;a href=&quot;%s&quot;&gt;必要なモジュール&lt;/a&gt; がインストールされているか確認してください。</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="window.py" line="85"/>
        <source>File toolbar</source>
        <translation>ファイルツールバー</translation>
    </message>
    <message>
        <location filename="window.py" line="87"/>
        <source>Edit toolbar</source>
        <translation>編集ツールバー</translation>
    </message>
    <message>
        <location filename="window.py" line="89"/>
        <source>Search toolbar</source>
        <translation>検索ツールバー</translation>
    </message>
    <message>
        <location filename="window.py" line="93"/>
        <source>New</source>
        <translation>新規</translation>
    </message>
    <message>
        <location filename="window.py" line="96"/>
        <source>Open</source>
        <translation>開く</translation>
    </message>
    <message>
        <location filename="window.py" line="99"/>
        <source>Set encoding</source>
        <translation>文字エンコーディング</translation>
    </message>
    <message>
        <location filename="window.py" line="1096"/>
        <source>Reload</source>
        <translation>再読み込み</translation>
    </message>
    <message>
        <location filename="window.py" line="105"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="window.py" line="109"/>
        <source>Save as</source>
        <translation>名前を付けて保存</translation>
    </message>
    <message>
        <location filename="window.py" line="111"/>
        <source>Next tab</source>
        <translation>次のタブへ</translation>
    </message>
    <message>
        <location filename="window.py" line="113"/>
        <source>Previous tab</source>
        <translation>前のタブへ</translation>
    </message>
    <message>
        <location filename="window.py" line="115"/>
        <source>Print</source>
        <translation>印刷</translation>
    </message>
    <message>
        <location filename="window.py" line="118"/>
        <source>Print preview</source>
        <translation>印刷プレビュー</translation>
    </message>
    <message>
        <location filename="window.py" line="120"/>
        <source>View HTML code</source>
        <translation>HTMLコードを表示</translation>
    </message>
    <message>
        <location filename="window.py" line="121"/>
        <source>Change editor font</source>
        <translation>エディターのフォントを変更</translation>
    </message>
    <message>
        <location filename="window.py" line="123"/>
        <source>Change preview font</source>
        <translation>プレビューのフォントを変更</translation>
    </message>
    <message>
        <location filename="window.py" line="125"/>
        <source>Find text</source>
        <translation>テキストを検索</translation>
    </message>
    <message>
        <location filename="window.py" line="129"/>
        <source>Preview</source>
        <translation>プレビュー</translation>
    </message>
    <message>
        <location filename="window.py" line="139"/>
        <source>Live preview</source>
        <translation>ライブプレビュー</translation>
    </message>
    <message>
        <location filename="window.py" line="144"/>
        <source>Table editing mode</source>
        <translation>表組みモード</translation>
    </message>
    <message>
        <location filename="window.py" line="148"/>
        <source>FakeVim mode</source>
        <translation>擬似Vimモード</translation>
    </message>
    <message>
        <location filename="window.py" line="153"/>
        <source>Fullscreen mode</source>
        <translation>フルスクリーンモード</translation>
    </message>
    <message>
        <location filename="window.py" line="588"/>
        <source>Preferences</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="window.py" line="163"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="window.py" line="166"/>
        <source>Undo</source>
        <translation>元に戻す</translation>
    </message>
    <message>
        <location filename="window.py" line="168"/>
        <source>Redo</source>
        <translation>やり直す</translation>
    </message>
    <message>
        <location filename="window.py" line="170"/>
        <source>Copy</source>
        <translation>コピー</translation>
    </message>
    <message>
        <location filename="window.py" line="172"/>
        <source>Cut</source>
        <translation>切り取り</translation>
    </message>
    <message>
        <location filename="window.py" line="174"/>
        <source>Paste</source>
        <translation>貼り付け</translation>
    </message>
    <message>
        <location filename="window.py" line="184"/>
        <source>Enable</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="window.py" line="185"/>
        <source>Set locale</source>
        <translation>ロケールの設定</translation>
    </message>
    <message>
        <location filename="window.py" line="186"/>
        <source>Use WebKit renderer</source>
        <translation>WebKitレンダラーを使用</translation>
    </message>
    <message>
        <location filename="window.py" line="196"/>
        <source>Show directory</source>
        <translation>ディレクトリを表示</translation>
    </message>
    <message>
        <location filename="window.py" line="197"/>
        <source>Next</source>
        <translation>次へ</translation>
    </message>
    <message>
        <location filename="window.py" line="199"/>
        <source>Previous</source>
        <translation>前へ</translation>
    </message>
    <message>
        <location filename="window.py" line="210"/>
        <source>Get help online</source>
        <translation>オンラインでヘルプを読む</translation>
    </message>
    <message>
        <location filename="window.py" line="211"/>
        <source>About ReText</source>
        <translation>ReTextについて</translation>
    </message>
    <message>
        <location filename="window.py" line="214"/>
        <source>About Qt</source>
        <translation>Qtについて</translation>
    </message>
    <message>
        <location filename="window.py" line="229"/>
        <source>Bold</source>
        <translation>太字</translation>
    </message>
    <message>
        <location filename="window.py" line="231"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location filename="window.py" line="233"/>
        <source>Underline</source>
        <translation>下線</translation>
    </message>
    <message>
        <location filename="window.py" line="245"/>
        <source>Symbols</source>
        <translation>シンボル</translation>
    </message>
    <message>
        <location filename="window.py" line="250"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="window.py" line="251"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="window.py" line="252"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="window.py" line="255"/>
        <source>Open recent</source>
        <translation>最近使用したファイル</translation>
    </message>
    <message>
        <location filename="window.py" line="267"/>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <location filename="window.py" line="288"/>
        <source>Spell check</source>
        <translation>スペルチェック</translation>
    </message>
    <message>
        <location filename="window.py" line="296"/>
        <source>Default markup</source>
        <translation>デフォルトマークアップ</translation>
    </message>
    <message>
        <location filename="window.py" line="299"/>
        <source>Formatting</source>
        <translation>書式</translation>
    </message>
    <message>
        <location filename="window.py" line="339"/>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <location filename="window.py" line="344"/>
        <source>Case sensitively</source>
        <translation>大文字と小文字を区別</translation>
    </message>
    <message>
        <location filename="window.py" line="492"/>
        <source>New document</source>
        <translation>新規文書</translation>
    </message>
    <message>
        <location filename="window.py" line="664"/>
        <source>Please, save the file somewhere.</source>
        <translation>どこかにファイルを保存してください。</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>Select one or several files to open</source>
        <translation>開きたいファイル（複数可）を選択してください</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>Supported files</source>
        <translation>サポートされているファイル</translation>
    </message>
    <message>
        <location filename="window.py" line="780"/>
        <source>All files (*)</source>
        <translation>すべてのファイル (*)</translation>
    </message>
    <message>
        <location filename="window.py" line="818"/>
        <source>Select file encoding from the list:</source>
        <translation>ファイルの文字エンコーディングを選んでください：</translation>
    </message>
    <message>
        <location filename="window.py" line="839"/>
        <source>Plain text (*.txt)</source>
        <translation>プレーンテキスト (*.txt)</translation>
    </message>
    <message>
        <location filename="window.py" line="842"/>
        <source>%s files</source>
        <comment>Example of final string: Markdown files</comment>
        <translation>%s ファイル</translation>
    </message>
    <message>
        <location filename="window.py" line="919"/>
        <source>Save file</source>
        <translation>ファイルを保存</translation>
    </message>
    <message>
        <location filename="window.py" line="884"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>読み取り専用ファイルのため保存できません。</translation>
    </message>
    <message>
        <location filename="window.py" line="909"/>
        <source>Export document to ODT</source>
        <translation>文書をODTにエクスポート</translation>
    </message>
    <message>
        <location filename="window.py" line="909"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>OpenDocumentテキストファイル (*.odt)</translation>
    </message>
    <message>
        <location filename="window.py" line="919"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>HTMLファイル (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="window.py" line="940"/>
        <source>Export document to PDF</source>
        <translation>文書をPDFにエクスポート</translation>
    </message>
    <message>
        <location filename="window.py" line="940"/>
        <source>PDF files (*.pdf)</source>
        <translation>PDFファイル (*.pdf)</translation>
    </message>
    <message>
        <location filename="window.py" line="960"/>
        <source>Print document</source>
        <translation>文書を印刷</translation>
    </message>
    <message>
        <location filename="window.py" line="984"/>
        <source>Export document</source>
        <translation>文書をエクスポート</translation>
    </message>
    <message>
        <location filename="window.py" line="1005"/>
        <source>Failed to execute the command:</source>
        <translation>コマンドの実行に失敗しました:</translation>
    </message>
    <message>
        <location filename="window.py" line="1080"/>
        <source>This file has been deleted by other application.
Please make sure you save the file before exit.</source>
        <translation>このファイルは他のアプリケーションによって削除されました。
終了する前にファイルを保存して下さい。</translation>
    </message>
    <message>
        <location filename="window.py" line="1087"/>
        <source>This document has been modified by other application.
Do you want to reload the file (this will discard all your changes)?
</source>
        <translation>この文書は他のアプリケーションによって変更されました。
再読み込みを行いますか(全ての変更は失われます)?
</translation>
    </message>
    <message>
        <location filename="window.py" line="1092"/>
        <source>If you choose to not reload the file, auto save mode will be disabled for this session to prevent data loss.</source>
        <translation>再読み込みを選択しない場合、データの消失を避けるために自動保存機能はこのセッションで無効になります。</translation>
    </message>
    <message>
        <location filename="window.py" line="1116"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>文書は変更されています。
変更内容を保存しますか？</translation>
    </message>
    <message>
        <location filename="window.py" line="1145"/>
        <source>HTML code</source>
        <translation>HTMLコード</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>ReText %s (using PyMarkups %s)</source>
        <translation>ReText %s(PyMarkups %s 利用)</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Simple but powerful editor for Markdown and reStructuredText</source>
        <translation>Markdown と reStructuredText のためのシンプルでパワフルなエディタ</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>作者: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Website</source>
        <translation>Webサイト</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>Markdown syntax</source>
        <translation>Markdown 記法</translation>
    </message>
    <message>
        <location filename="window.py" line="1156"/>
        <source>reStructuredText syntax</source>
        <translation>reStructuredText 文法</translation>
    </message>
    <message>
        <location filename="window.py" line="207"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1039"/>
        <source>Alt text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="1040"/>
        <source>Link text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="201"/>
        <source>Replace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="203"/>
        <source>Replace all</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="342"/>
        <source>Replace with</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="860"/>
        <source>Cannot save to file which is open in another tab!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="window.py" line="191"/>
        <source>Use WebEngine (Chromium) renderer</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
